aboutsummaryrefslogtreecommitdiff
path: root/modules/cj-window-toggle-lib.el
diff options
context:
space:
mode:
authorCraig Jennings <c@cjennings.net>2026-05-10 15:31:27 -0500
committerCraig Jennings <c@cjennings.net>2026-05-10 15:31:27 -0500
commit8c12629f8c4c8726b7b74ad3912abd9cd1cade9c (patch)
treeac24310962cebf647311c17368c0e5ff929c219d /modules/cj-window-toggle-lib.el
parenta2e41803d7d29a43ed37a5cf9fd7fe53ca5c15b5 (diff)
downloaddotemacs-8c12629f8c4c8726b7b74ad3912abd9cd1cade9c.tar.gz
dotemacs-8c12629f8c4c8726b7b74ad3912abd9cd1cade9c.zip
refactor(cj-window-geometry): rename to cj-window-geometry-lib
Same naming-convention fix as the other library renames in this series. Rename modules/cj-window-geometry.el -> modules/cj-window-geometry-lib.el and tests/test-cj-window-geometry.el -> tests/test-cj-window-geometry-lib.el. Update provide forms, file headers, and the (require 'cj-window-geometry) call sites in cj-window-toggle-lib.el, ai-vterm.el, vterm-config.el, and the test file. No behavior change.
Diffstat (limited to 'modules/cj-window-toggle-lib.el')
-rw-r--r--modules/cj-window-toggle-lib.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/cj-window-toggle-lib.el b/modules/cj-window-toggle-lib.el
index 868ee99f..6021c2eb 100644
--- a/modules/cj-window-toggle-lib.el
+++ b/modules/cj-window-toggle-lib.el
@@ -12,12 +12,12 @@
;; helpers. Both helpers are pure with respect to their arguments;
;; the side effects are confined to the named state variables.
;;
;; Pulls the geometry primitives in from cj-window-geometry.el.
;;; Code:
(require 'cl-lib)
-(require 'cj-window-geometry)
+(require 'cj-window-geometry-lib)
(defun cj/window-toggle-capture-state (window default-direction
direction-var size-var)
@@ -12,12 +12,12 @@
;; the side effects are confined to the named state variables.
;;
-;; Pulls the geometry primitives in from cj-window-geometry.el.
+;; Pulls the geometry primitives in from cj-window-geometry-lib.el.
;;; Code:
(require 'cl-lib)